# YDL

YDL is a simple inter-process communication framework. It is cross-platform and built on TCP sockets.

The name stands for Yheavyweight Dcommunications and Lmarshalling, with the acronym being pronounced "yodel".

## Installation

You can install YDL from PyPI:
```
python -m pip install ydl-ipc
```
